aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorhjk <hjk@qt.io>2019-06-12 14:47:41 +0200
committerTobias Hunger <tobias.hunger@qt.io>2019-06-12 13:43:35 +0000
commit0981a0af25e95fa05258f00b74e2f0cf16cd2a04 (patch)
tree3d97c312eb391f5cd40870737050a30baf9344ef /src
parent2942ae876cba9c2082dc383842fbd781766ddef8 (diff)
CMake: Compile fix
Amends d5383c92a8392b Change-Id: Ie0743ac01adbae7eff1d84979acaed68474bc760 Reviewed-by: Tobias Hunger <tobias.hunger@qt.io>
Diffstat (limited to 'src')
-rw-r--r--src/plugins/cmakeprojectmanager/builddirmanager.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/plugins/cmakeprojectmanager/builddirmanager.h b/src/plugins/cmakeprojectmanager/builddirmanager.h
index ff93e48743..8c166fc0fd 100644
--- a/src/plugins/cmakeprojectmanager/builddirmanager.h
+++ b/src/plugins/cmakeprojectmanager/builddirmanager.h
@@ -90,11 +90,12 @@ public:
enum ReparseParameters { REPARSE_DEFAULT = 0, // use defaults
REPARSE_URGENT = 1, // Do not wait for more requests, start ASAP
- REPARSE_FORCE_CONFIGURATION = 2, // Force configuration arguments to cmake
- REPARSE_CHECK_CONFIGURATION = 4, // Check and warn if on-disk config and QtC config differ
- REPARSE_SCAN = 8,
- REPARSE_IGNORE = 16, // Do not reparse:-)
- REPARSE_FAIL = 32 // Do not reparse and raise a warning
+ REPARSE_FORCE_CMAKE_RUN = 2, // Force cmake to run
+ REPARSE_FORCE_CONFIGURATION = 4, // Force configuration arguments to cmake
+ REPARSE_CHECK_CONFIGURATION = 8, // Check and warn if on-disk config and QtC config differ
+ REPARSE_SCAN = 16,
+ REPARSE_IGNORE = 32, // Do not reparse:-)
+ REPARSE_FAIL = 64 // Do not reparse and raise a warning
};
signals: